==> 0.3.2.tar.gz: lib/src/widget/entity_table/table_tile.dart <==
import 'package:flutter/material.dart';
import 'package:modular_system_core/modular_system_core.dart';

class TableTile extends StatefulWidget {
  // ignore: use_key_in_widget_constructors
  const TableTile({
    required this.index,
    required this.appViewModel,
    required this.viewModel,
    required this.child,
  });

  final int index;
  final AppViewModel appViewModel;
  final EntityTableViewModel viewModel;
  final Widget child;

  @override
  State<TableTile> createState() {
    // ignore: no_logic_in_create_state
    return _TableTileState(
      index: index,
      appViewModel: appViewModel,
      viewModel: viewModel,
      child: child,
    );
  }
}

class _TableTileState extends State<TableTile> {
  _TableTileState({
    required this.index,
    required this.appViewModel,
    required this.viewModel,
    required this.child,
  }) {
    subscribeToEvents();
  }

  final int index;
  final AppViewModel appViewModel;
  final EntityTableViewModel viewModel;
  final Widget child;
  late bool selectorOn = viewModel.state.selectorOn;
  late bool isSelected = viewModel.state.selectedTiles
      .where((element) => element == index)
      .isNotEmpty;

  @override
  void dispose() {
    unsubscribeToEvents();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      key: UniqueKey(),
      padding: const EdgeInsets.symmetric(horizontal: 5),
      child: Row(
        children: [
          selectorOn
              ? Checkbox(
                  value: isSelected,
                  activeColor: appViewModel.colorScheme.tertiary,
                  side: BorderSide(
                    color: appViewModel.colorScheme.onBackground,
                  ),
                  onChanged: (value) {
                    setState(() {
                      isSelected = !isSelected;
                      if (isSelected) {
                        viewModel.state.selectedTiles.add(index);
                      } else {
                        viewModel.state.selectedTiles.remove(index);
                      }
                      viewModel.events.tileSelectedEvent.invoke();
                    });
                  },
                )
              : Container(),
          Expanded(
            child: child,
          ),
        ],
      ),
    );
  }

  void subscribeToEvents() {
    viewModel.events.selectorStateChangedEvent.subscribe(onSelector);
  }

  void unsubscribeToEvents() {
    viewModel.events.selectorStateChangedEvent.unsubscribe(onSelector);
  }

  void onSelector(dynamic data) {
    setState(() {
      selectorOn = !selectorOn;
    });
  }
}

class TableTileTemplate<T> extends StatefulWidget {
  // ignore: use_key_in_widget_constructors
  const TableTileTemplate({
    required this.data,
  });

  final T data;

  @override
  State<TableTileTemplate> createState() {
    // ignore: no_logic_in_create_state
    return _TableTileTemplateState<T>(
      data: data,
    );
  }
}

class _TableTileTemplateState<T> extends State<TableTileTemplate> {
  _TableTileTemplateState({
    required this.data,
  });

  final T data;

  @override
  Widget build(BuildContext context) {
    return Container();
  }
}

==> 0.7.9.tar.gz: lib/src/widget/entity_table/table_tile.dart <==
import 'package:flutter/material.dart';
import 'package:modular_system_core/modular_system_core.dart';

class TableTile extends StatefulWidget {
  // ignore: use_key_in_widget_constructors
  const TableTile({
    required this.index,
    required this.appViewModel,
    required this.viewModel,
    required this.child,
  });

  final int index;
  final AppViewModel appViewModel;
  final EntityTableViewModel viewModel;
  final Widget child;

  @override
  State<TableTile> createState() {
    // ignore: no_logic_in_create_state
    return _TableTileState(
      index: index,
      appViewModel: appViewModel,
      viewModel: viewModel,
      child: child,
    );
  }
}

class _TableTileState extends State<TableTile> {
  _TableTileState({
    required this.index,
    required this.appViewModel,
    required this.viewModel,
    required this.child,
  }) {
    subscribeToEvents();
  }

  final int index;
  final AppViewModel appViewModel;
  final EntityTableViewModel viewModel;
  final Widget child;
  late bool selectorOn = viewModel.state.selectorOn;
  late bool isSelected = viewModel.state.selectedTiles
      .where((element) => element == index)
      .isNotEmpty;

  void subscribeToEvents() {
    viewModel.events.setSelectorMode.subscribe(onSetSelectorMode);
  }

  void unsubscribeToEvents() {
    viewModel.events.setSelectorMode.unsubscribe(onSetSelectorMode);
  }

  @override
  void dispose() {
    unsubscribeToEvents();
    super.dispose();
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      key: UniqueKey(),
      padding: const EdgeInsets.symmetric(horizontal: 5),
      child: Row(
        children: [
          selectorOn
              ? Checkbox(
                  value: isSelected,
                  activeColor: appViewModel.colorScheme.tertiary,
                  side: BorderSide(
                    color: appViewModel.colorScheme.onBackground,
                  ),
                  onChanged: (value) {
                    setState(() {
                      isSelected = !isSelected;
                      if (isSelected) {
                        viewModel.state.selectedTiles.add(index);
                      } else {
                        viewModel.state.selectedTiles.remove(index);
                      }
                      viewModel.events.setSelectedTiles
                          .invoke(viewModel.state.selectedTiles);
                    });
                  },
                )
              : Container(),
          Expanded(
            child: child,
          ),
        ],
      ),
    );
  }

  void onSetSelectorMode(bool selectorState) {
    setState(() {
      selectorOn = selectorState;
    });
  }
}

class TableTileTemplate<T> extends StatefulWidget {
  // ignore: use_key_in_widget_constructors
  const TableTileTemplate({
    required this.data,
  });

  final T data;

  @override
  State<TableTileTemplate> createState() {
    // ignore: no_logic_in_create_state
    return _TableTileTemplateState<T>(
      data: data,
    );
  }
}

class _TableTileTemplateState<T> extends State<TableTileTemplate> {
  _TableTileTemplateState({
    required this.data,
  });

  final T data;

  @override
  Widget build(BuildContext context) {
    return Container();
  }
}
